pub enum PolicyVerb {
Reconcile(ReconcileArgs),
}Expand description
The one verb, previewing by default.
Variants
Reconcile(ReconcileArgs)
Add the rule that authorizes an active declaration to the adopted specification that owns it, where the local specifications lack it.