pub fn run(_ctx: &AppContext, args: &DocsArgs) -> Result<(), AppError>Expand description
Read the corpus this binary carries.
Errors
AppError::Usage when a query matches no topic or more than one.
pub fn run(_ctx: &AppContext, args: &DocsArgs) -> Result<(), AppError>Read the corpus this binary carries.
AppError::Usage when a query matches no topic or more than one.