pub fn run(ctx: &AppContext, args: KiArgs) -> Result<(), AppError>Expand description
Run one sdd ki verb.
Errors
AppError::Usage when the target is neither absolute nor ., and
AppError::Io when a record cannot be read.
pub fn run(ctx: &AppContext, args: KiArgs) -> Result<(), AppError>Run one sdd ki verb.
AppError::Usage when the target is neither absolute nor ., and
AppError::Io when a record cannot be read.