pub fn run(
_ctx: &AppContext,
shelf: &Shelf,
args: ReadArgs,
) -> Result<(), AppError>Expand description
Read one document from a shelf, or list it.
Errors
AppError::Usage when the name resolves to nothing.
pub fn run(
_ctx: &AppContext,
shelf: &Shelf,
args: ReadArgs,
) -> Result<(), AppError>Read one document from a shelf, or list it.
AppError::Usage when the name resolves to nothing.