run

Function run 

pub fn run(ctx: &AppContext, args: StageArgs) -> Result<(), AppError>
Render a stage, or remove one.

Errors

AppError::Usage for a target or stage path the arguments cannot mean, AppError::Refused where a stage is already there or a cleanup target is not a stage, and I/O errors writing the stage.