pub fn run(ctx: &GateCtx, _files: &[String]) -> GateResultExpand description
Judge every agent digest in the repository.
Errors
GateError::Io when a digest cannot be read, and GateError::Debt
when the debt file cannot be trusted.
pub fn run(ctx: &GateCtx, _files: &[String]) -> GateResultJudge every agent digest in the repository.
GateError::Io when a digest cannot be read, and GateError::Debt
when the debt file cannot be trusted.