pub fn run(ctx: &GateCtx, _files: &[String]) -> GateResultExpand description
Judge every spec under the documentation root.
Errors
GateError::Io when a spec cannot be read, and GateError::Debt
when the debt file cannot be trusted.
pub fn run(ctx: &GateCtx, _files: &[String]) -> GateResultJudge every spec under the documentation root.
GateError::Io when a spec cannot be read, and GateError::Debt
when the debt file cannot be trusted.