pub fn run(ctx: &GateCtx, _files: &[String]) -> GateResultExpand description
Judge the tracking registry.
Errors
crate::gates::GateError::Io when the registry is present but cannot be
read.
pub fn run(ctx: &GateCtx, _files: &[String]) -> GateResultJudge the tracking registry.
crate::gates::GateError::Io when the registry is present but cannot be
read.