acyclic

Function acyclic 

pub fn acyclic(decisions: &[Decision]) -> Result<(), String>
Whether the decisions form an acyclic graph.

Errors

The identifier of a decision that is part of a cycle or that names a prerequisite nothing offers.