pub fn render_block(docs_root: &str, selection: &WritingStyle) -> StringExpand description
The complete marked block for the given documentation root and writing-style selection, newline-terminated.
pub fn render_block(docs_root: &str, selection: &WritingStyle) -> StringThe complete marked block for the given documentation root and writing-style selection, newline-terminated.