rule_block

Function rule_block 

pub fn rule_block(seed: &str, rule: RuleId) -> Option<String>
The sentinel’s rule block, from the heading to the line before the next heading, as the embedded seed states it.