pub fn registry_path(docs_root: &Utf8Path) -> Utf8PathBufExpand description
Where the registry lives, relative to the repository root.
pub fn registry_path(docs_root: &Utf8Path) -> Utf8PathBufWhere the registry lives, relative to the repository root.