pub struct VerifyReport {
pub lines: Vec<String>,
pub failures: usize,
pub managed_drift: usize,
pub adopted_drift: usize,
}Expand description
What a verification run reports.
Fields
lines: Vec<String>Every line to print, failures and notes alike, in order.
failures: usizeHow many lines are failures.
managed_drift: usizeHow many managed files are missing, symlinked, or byte-drifted.
adopted_drift: usizeHow many adopted files await reconciliation.