sync_parent

Function sync_parent 

pub fn sync_parent(path: &Utf8Path) -> Result<()>
Flush the directory holding path, where it has one.

Errors

Any I/O error other than a refusal to sync a directory at all.