pub fn source_bytes(source: &str) -> Result<Vec<u8>, AppError>
The bytes one payload source carries, from this binary’s own sources.
AppError::Refused where this release does not carry the source.
AppError::Refused