pub fn validate_docs_scratch_path(
path: &Utf8Path,
) -> Result<(), DeclaredPathError>Expand description
Whether a recorded docs-scratch path is one a reader can resolve.
Errors
DeclaredPathError for a path that is empty or absolute.
pub fn validate_docs_scratch_path(
path: &Utf8Path,
) -> Result<(), DeclaredPathError>Whether a recorded docs-scratch path is one a reader can resolve.
DeclaredPathError for a path that is empty or absolute.