pub fn run(ctx: &GateCtx, _files: &[String]) -> GateResultExpand description
Judge every chapter and catalog, honoring the debt list.
Errors
crate::gates::GateError::Io when a matched file cannot be read.
pub fn run(ctx: &GateCtx, _files: &[String]) -> GateResultJudge every chapter and catalog, honoring the debt list.
crate::gates::GateError::Io when a matched file cannot be read.