pub fn apply(request: &Request<'_>) -> Result<Result, AppError>Expand description
Execute one stored plan.
Errors
AppError::Refused when the plan is not ready, when a semantic input
moved, or when an operation could not be applied and the target was put
back. AppError::Unrecovered when a run could not be put back.