pub fn append_to_requirements(text: &str, block: &str) -> Option<String>
The file with the block appended to the end of its Requirements section, or None where the file has no such section to append to.
None