pub fn clean(path: &Utf8Path) -> Result<Vec<String>, AppError>Expand description
Remove one stage this tool wrote, and refuse anything else.
Errors
AppError::Usage for a relative path, and AppError::Refused for a
path that is not a stage, a stage whose receipt names another root, a
link, or a root this tool will not recurse into.